@@ -19,12 +19,15 @@ from rb.similarity.vector_model import VectorModel
 
 
 class CnaGraph:
-    def __init__(self, docs: Union[TextElement, List[TextElement]], models: List[VectorModel], pairwise = True, compute_filtered_graph = True):
+    def __init__(self, docs: Union[TextElement, List[TextElement]], models: List[VectorModel], 
+        pairwise = True, compute_filtered_graph = True, window=1):
+       
         if isinstance(docs, TextElement):
             docs = [docs]
         self.graph = nx.MultiDiGraph()
         self.models = models
         self.pairwise = pairwise
+        self.window = window
         self.compute_filtered_graph = compute_filtered_graph
         if all(isinstance(doc, Community) or isinstance(doc, MetaDocument) for doc in docs):
             for doc in docs:
@@ -35,11 +38,11 @@ class CnaGraph:
                         sim = model.similarity(conv, doc)
                         self.graph.add_edge(conv, doc, type=EdgeType.SEMANTIC, model=model, value=sim)
                     self.graph.add_edge(conv, doc, type=EdgeType.PART_OF)
-                    self.add_links(nodes, pairwise)
+                    self.add_links(nodes)
         else:
             for doc in docs:
                 self.add_element(doc)
-            self.add_links(self.graph.nodes, pairwise)
+            self.add_links(self.graph.nodes)
         
         self.add_coref_links()
         self.add_explicit_links()
@@ -47,7 +50,7 @@ class CnaGraph:
             self.filtered_graph = self.create_filtered_graph()
             self.importance = self.compute_importance()
         
-    def add_links(self, nodes, pairwise: bool):
+    def add_links(self, nodes):
         levels = dict()
         for n in nodes:
             if not n.is_word():
@@ -56,10 +59,10 @@ class CnaGraph:
                 else:
                     levels[n.depth] = [n]
         for depth, elements in levels.items():
-            self.add_lexical_links(elements, lambda w: w.pos in [POS.ADJ, POS.ADV, POS.NOUN, POS.VERB], OverlapType.CONTENT_OVERLAP, pairwise)
-            self.add_lexical_links(elements, lambda w: w.pos in [POS.NOUN, POS.VERB], OverlapType.TOPIC_OVERLAP, pairwise)
-            self.add_lexical_links(elements, lambda w: w.pos in [POS.NOUN, POS.PRON], OverlapType.ARGUMENT_OVERLAP, pairwise)
-            self.add_semantic_links(elements, pairwise)
+            self.add_lexical_links(elements, lambda w: w.pos in [POS.ADJ, POS.ADV, POS.NOUN, POS.VERB], OverlapType.CONTENT_OVERLAP)
+            self.add_lexical_links(elements, lambda w: w.pos in [POS.NOUN, POS.VERB], OverlapType.TOPIC_OVERLAP)
+            self.add_lexical_links(elements, lambda w: w.pos in [POS.NOUN, POS.PRON], OverlapType.ARGUMENT_OVERLAP)
+            self.add_semantic_links(elements)
 
     def add_element(self, element: TextElement) -> List[TextElement]:
         self.graph.add_node(element)
@@ -75,14 +78,14 @@ class CnaGraph:
             self.graph.add_edges_from(zip(element.components[:-1], element.components[1:]), type=EdgeType.ADJACENT)
         return result
 
-    def add_semantic_links(self, elements: List[TextElement], pairwise: bool):
+    def add_semantic_links(self, elements: List[TextElement]):
         for i, a in enumerate(elements[:-1]):
-            if pairwise:
+            if self.pairwise:
                 for b in elements[i+1:]:
                     self.add_semantic_edge_between_two_words(a, b)
             else:
-                b = elements[i+1]
-                self.add_semantic_edge_between_two_words(a, b)
+                for b in elements[i+1:i+1+self.window]:
+                    self.add_semantic_edge_between_two_words(a, b)
             
     def add_semantic_edge_between_two_words(self, a, b):
         for model in self.models:
@@ -90,15 +93,15 @@ class CnaGraph:
             self.graph.add_edge(a, b, type=EdgeType.SEMANTIC, model=model, value=sim)
             self.graph.add_edge(b, a, type=EdgeType.SEMANTIC, model=model, value=sim)
         
-    def add_lexical_links(self, elements: List[TextElement], test: Callable[[Word], bool], link_type: OverlapType, pairwise: bool):
+    def add_lexical_links(self, elements: List[TextElement], test: Callable[[Word], bool], link_type: OverlapType):
         words = {element: {word.lemma for word in element.get_words() if test(word)} for element in elements}
         for i, a in enumerate(elements[:-1]):
-            if pairwise:
+            if self.pairwise:
                 for b in elements[i+1:]:
                     self.add_lexical_overlap_edge_between_two_words(words, a, b, link_type)
             else:
-                b = elements[i+1]
-                self.add_lexical_overlap_edge_between_two_words(words, a, b, link_type)
+                for b in elements[i+1:i+1+self.window]:
+                    self.add_lexical_overlap_edge_between_two_words(words, a, b, link_type)
 
     def add_lexical_overlap_edge_between_two_words(self, words, a, b, link_type):
         words_a = words[a]
